@@ -3,7 +3,7 @@ package WordList;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-22'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.6.2'; # VERSION
+our $VERSION = '0.7.0'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -31,7 +31,13 @@ sub new {
             if $param_spec->{$param_name}{req} && !exists($params{$param_name});
     }
 
-    bless [undef, undef, \%params], $class;
+    bless {
+        params => \%params,
+
+        # we store this because applying roles to object will rebless the object
+        # into some other package.
+        orig_class => $class,
+    }, $class;
 }
 
 sub each_word {
@@ -153,7 +159,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.6.2 of WordList (from Perl distribution WordList), released on 2020-05-22.
+This document describes version 0.7.0 of WordList (from Perl distribution WordList), released on 2020-05-22.
 
 =head1 SYNOPSIS
 
